% dist2conv.m: convert between Distance and Convergence Angle.
% Usage: out = dist2conv(dist_or_conv, ipd, inputValue);
%
% where dist_or_conv = 1 converts Distance to Convergence Angle (in deg)
%                    = 2 converts Convergence Angle (in deg) to Distance
% 		ipd is interpupillary distance (ANY units).
% 		inputValue is the Target Distance to be converted (SAME units) or
%					  the Convergence Angle to be converted (in deg).
% Distance and Interpupillary Distance must be SAME units.
%
% Alternatively, you can simply type "dist2conv" and follow the prompts

% Written by:  L.F. Dell'Osso
% Based on va2naf.m
%              June 2000 (last mod: 5/22/02)

function out = dist2conv(dist_or_conv, ipd, inpVal)

if nargin == 0
   dist_or_conv = -1;
   ipd=-1;
   inpVal=-1;
   verbose=1;
 else
   verbose=0;
end

while(dist_or_conv<1) | (dist_or_conv>2)
   disp(' 1) Convert Distance to Convergence Angle')
   disp(' 2) Convert Convergence Angle to Distance')
   dist_or_conv = input(' --> ');
end

if dist_or_conv == 1
   dist=inpVal;
   while (dist<0)
      ipd = input('Enter the Interpupillary Distance (ANY units): ');
      dist = input('Enter the Target Distance (SAME units): ');
   end
   conv = 360*atan(ipd/(2*dist))/pi;
   convpd = 1.75*conv;
   if verbose
      disp(['  Convergence Angle calculated to be ' num2str(conv,2) ' deg = ' num2str(convpd,2) ' D'])
      return
   end
   out = conv;
 else
   conv=inpVal;
   while (conv<0)
      ipd = input('Enter the Interpupillary Distance (ANY units): ');
      conv = input('Enter the Convergence Angle (deg): ');
   end
   dist = ipd/(2*tan(conv*pi/360));
   if verbose
      disp(['  Target Distance calculated to be ' num2str(dist,3) ' (SAME units)'])
      return
   end
   out = dist;
end
