% mainseqRSR.m: Plot max. velocity of saccade vs amplitude.
%               Plot saccade duration vs amplitdue.
%               Modification of "mainseq.m" for RSR normals study 
% written by:   Jonathan Jacobs
%               January 1996 - January 2001  (last mod: 01/19/01)

%% Same as mainseqRSR.m and mainseqRSR2.m EXCEPT that saccadic magnitude
%% is calculated using the FIRST mod, i.e. add initial segment

% We will go through the control point lists, a column at a time, 
% extracting the real points from the NaNs.  The stripped 
% column is then used to index into the proper column of 
% the position or velocity data array.  The points are concatenated
% into vectors (love that transpose operator) and plotted.

saci_dist=[]; sacp_dist=[]; sacf_dist=[]; 
true_max_vel=[]; norm_max_vel=[];
sacv_dur=[]; sacp_dur=[]; init_eye_vel=[];
sacv1_dist=[]; sacv2_dist=[];
cyc_end_list = []; cyc_beg_list = [];

mrkrsz = 3;

if ~exist( 'pos')
   pos = [];
end
if isempty(pos)
   disp( 'You need to run "pickdata" first.' )
   return
end

[nRows, nCols] = size( sacp_on_mat );
for z = 1:nCols
   % whack out the 'NaNs'
   num_pts = length( find(sacp_on_mat(:,z) < 100000) );

   % extract the list of 'on' points
   this_sacv_on = sacv_on_mat( 1:num_pts,z );
   this_sacp_on = sacp_on_mat( 1:num_pts,z );

   % extract the list of 'off' points
   this_sacv_off = sacv_off_mat( 1:num_pts,z );
   this_sacp_off = sacp_off_mat( 1:num_pts,z );

   %calculate and concatenate the saccade duaration
   this_samp_freq = samp_f_mat(z);
   this_sacv_dur = 1000 * (this_sacv_off - this_sacv_on) / this_samp_freq;
   this_sacp_dur = 1000 * (this_sacp_off - this_sacp_on) / this_samp_freq;
   sacv_dur = [ sacv_dur' this_sacv_dur' ]';
   sacp_dur = [ sacp_dur' this_sacp_dur' ]';

   % extract the list of 'max_vel' points
   this_max_v_pt = max_v_pt_mat( 1:num_pts,z );

   % calculate and concatenate the saccade mag and max velocity
   this_saci_dist = abs( pos(this_sacp_on,z) - pos(this_sacv_on,z) );
   this_sacp_dist = abs( pos(this_sacp_on,z) - pos(this_sacp_off,z) );
   this_sacf_dist = abs( pos(this_sacv_off,z) - pos(this_sacp_off,z) );

   this_base_eye_vel = abs( vel(this_sacv_on,z) );
   this_norm_max_vel = abs( vel(this_max_v_pt,z) );
   this_true_max_vel = abs( vel(this_sacv_on,z) - vel(this_max_v_pt,z) );

   saci_dist = [ saci_dist' this_saci_dist' ]';
   sacp_dist = [ sacp_dist' this_sacp_dist' ]';
   sacf_dist = [ sacf_dist' this_sacf_dist' ]';

   temp_ind1      = ~isnan(cycle_end_mat(:,z));
   this_cycle_end = cycle_end_mat(temp_ind1,z);
   cyc_end_list   = [ cyc_end_list' this_cycle_end' ]';

   temp_ind2      = ~isnan(cycle_beg_mat(:,z));
   this_cycle_beg = cycle_beg_mat(temp_ind2,z); 
   cyc_beg_list   = [ cyc_beg_list' this_cycle_beg' ]';

   init_eye_vel  = [ init_eye_vel'  this_base_eye_vel' ]';
   norm_max_vel  = [ norm_max_vel'  this_norm_max_vel' ]';
   true_max_vel  = [ true_max_vel'  this_true_max_vel' ]';
end

sacp1_dist = saci_dist  + sacp_dist;
sacp2_dist = sacp1_dist + sacf_dist;

%% for RSR experiments:
%% The the next-to-last data column "cycle_beg_mat" is the step size.
%% The last data column, "cycle_end_mat" is the ramp velocity.
%% We want to partition the list by these value so we can plot 
%% each velocity/with/anti as a separate color.

ind0  = find( cyc_end_list == 0 );

with30 = find( sign(cyc_end_list)==sign(cyc_beg_list) & abs(cyc_end_list)==30 );
with20 = find( sign(cyc_end_list)==sign(cyc_beg_list) & abs(cyc_end_list)==20 );
with10 = find( sign(cyc_end_list)==sign(cyc_beg_list) & abs(cyc_end_list)==10 );
with_all = find( sign(cyc_end_list)==sign(cyc_beg_list) & cyc_end_list~=0 );

anti30 = find( sign(cyc_end_list)~=sign(cyc_beg_list) & abs(cyc_end_list)==30 );
anti20 = find( sign(cyc_end_list)~=sign(cyc_beg_list) & abs(cyc_end_list)==20 );
anti10 = find( sign(cyc_end_list)~=sign(cyc_beg_list) & abs(cyc_end_list)==10 );
anti_all = find( sign(cyc_end_list)~=sign(cyc_beg_list) & cyc_end_list~=0 );

%% Plot legend:
%% + = with
%% x = anti
%% . = no SP

% now let's plot these suckers
% generate main sequence lines for comparison
max_ampl = 1.25 * max(sacp_dist);
ampl_vec = 0:0.1:max_ampl;

% From Becker: "Metrics" in "Neurobiology of saccadic eye movements"
% edited by Wurtz & Goldberg
% (Becker got it wrong! Yarbus should be '0.4', not '0.2')
%dur_yar = (ampl_vec .^ 0.2)  * 21;
dur_yar = (ampl_vec .^ 0.4)  * 21;
dur_bah = (ampl_vec .^ 0.15) * 26;
PV_ZS   = (ampl_vec .^ 1.0)  * 60;
PV_Bah  = (ampl_vec .^ 0.9)  * 80;

% PV from Becker
PV_Bec = 608*(ampl_vec./(ampl_vec+7.6));

% PV relationship from Boghen et al. (IOVS Aug 74)
bog_x   = [  0   1   5  10  20  30];
PV_bog  = [ 15  65 189 288 385 428];
PV_bogl = [NaN NaN 145 196 213 227];
PV_bogh = [NaN NaN 213 377 555 625];

if length(what_f_names) > 65
   [num, width] = size(what_files);
   files_str = [num2str(num) ' files'];
 else
   files_str = what_f_names;
end

figure('Name','Peak Vel vs Amplitude','NumberTitle','off');
orient portrait

subplot(2,2,1)
title([files_str])
hold on; box on
plot( sacp1_dist(ind0),      norm_max_vel(ind0),   'w.')
l1=plot( sacp1_dist(with10), norm_max_vel(with10), 'r+');
set(l1,'markersize',mrkrsz);
l1=plot( sacp1_dist(with20), norm_max_vel(with20), 'g+');
set(l1,'markersize',mrkrsz);
l1=plot( sacp1_dist(with30), norm_max_vel(with30), 'b+');
set(l1,'markersize',mrkrsz);
l1=plot( sacp1_dist(anti10), norm_max_vel(anti10), 'rx');
set(l1,'markersize',mrkrsz);
l1=plot( sacp1_dist(anti20), norm_max_vel(anti20), 'gx');
set(l1,'markersize',mrkrsz);
l1=plot( sacp1_dist(anti30), norm_max_vel(anti30), 'bx');
set(l1,'markersize',mrkrsz);
set(gca,'Xlim',[0 max_ampl]);
pvlines
ylabel('Unmod. Peak Vel. (/sec)')

subplot(2,2,2)
hold on; box on
plot( sacp1_dist(ind0),      true_max_vel(ind0),   'w.')
l1=plot( sacp1_dist(with10), true_max_vel(with10), 'r+');
set(l1,'markersize',mrkrsz);
l1=plot( sacp1_dist(with20), true_max_vel(with20), 'g+');
set(l1,'markersize',mrkrsz);
l1=plot( sacp1_dist(with30), true_max_vel(with30), 'b+');
set(l1,'markersize',mrkrsz);
l1=plot( sacp1_dist(anti10), true_max_vel(anti10), 'rx');
set(l1,'markersize',mrkrsz);
l1=plot( sacp1_dist(anti20), true_max_vel(anti20), 'gx');
set(l1,'markersize',mrkrsz);
l1=plot( sacp1_dist(anti30), true_max_vel(anti30), 'bx');
set(l1,'markersize',mrkrsz);
set(gca,'Xlim',[0 max_ampl]);
pvlines
ylabel('Corrected Peak Vel. (/sec)')

subplot(2,2,3)
hold on ;box on
plot( sacp1_dist(ind0),         norm_max_vel(ind0),     'w.')
l1=plot( sacp1_dist(with_all),  norm_max_vel(with_all), 'm+');
set(l1,'markersize',mrkrsz);
l1=plot( sacp1_dist(anti_all),  norm_max_vel(anti_all), 'bx');
set(l1,'markersize',mrkrsz);
set(gca,'Xlim',[0 max_ampl]);
pvlines
xlabel('Sac. Size Mod. 1 ()')
ylabel('Unmod. Peak Vel. (/sec)')

subplot(2,2,4)
hold on; box on
plot( sacp1_dist(ind0),        true_max_vel(ind0),     'w.')
l1=plot( sacp1_dist(with_all), true_max_vel(with_all), 'm+');
set(l1,'markersize',mrkrsz);
l1=plot( sacp1_dist(anti_all), true_max_vel(anti_all), 'bx');
set(l1,'markersize',mrkrsz);
set(gca,'Xlim',[0 max_ampl]);
pvlines
xlabel('Sac. Size Mod. 1 ()')
ylabel('Corrected Peak Vel. (/sec)')

figure('Name','Peak Vel vs Amplitude (Aggregate)','NumberTitle','off');
subplot(2,1,1)
title([files_str '  (Aggregate)'])
hold on; box on
plot(sacp1_dist, norm_max_vel, 'w.');
set(gca,'Xlim',[0 max_ampl]);
pvlines
xlabel('Sac. Size Mod. 1 ()')
ylabel('Unmod. Peak Vel. (/sec)')

subplot(2,1,2)
hold on; box on
plot(sacp1_dist, true_max_vel, 'w.');
set(gca,'Xlim',[0 max_ampl]);
pvlines
xlabel('Sac. Size Mod. 1 ()')
ylabel('Corrected Peak Vel. (/sec)')

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if length(what_f_names) > 65
   [num, width] = size(what_files);
   files_str = [num2str(num) ' files'];
 else
   files_str = what_f_names;
end

figure('Name','Duration vs Amplitude','NumberTitle','off');
orient portrait
%orient landscape

subplot(2,2,1)
title([files_str])
hold on; box on
plot( sacp1_dist(ind0),      sacp1_dur(ind0),   'w.')
l1=plot( sacp1_dist(with10), sacp1_dur(with10), 'r+');
set(l1,'markersize',mrkrsz);
l1=plot( sacp1_dist(with20), sacp1_dur(with20), 'g+');
set(l1,'markersize',mrkrsz);
l1=plot( sacp1_dist(with30), sacp1_dur(with30), 'b+');
set(l1,'markersize',mrkrsz);
l1=plot( sacp1_dist(anti10), sacp1_dur(anti10), 'rx');
set(l1,'markersize',mrkrsz);
l1=plot( sacp1_dist(anti20), sacp1_dur(anti20), 'gx');
set(l1,'markersize',mrkrsz);
l1=plot( sacp1_dist(anti30), sacp1_dur(anti30), 'bx');
set(l1,'markersize',mrkrsz);
max_y = max( max(sacp1_dur), max(dur_bah) );
%plot(ampl_vec, dur_bah, 'b')
temp=plot(ampl_vec, dur_yar,  'c');
set(temp,'Color',[0.75 0.75 0.75]);
set(gca,'Xlim',[0 max_ampl]);
ylabel('Sac. Dur. (msec) [pdcp]')

subplot(2,2,2)
hold on; box on
plot( sacp1_dist(ind0),      sacv_dur(ind0),   'w.')
l1=plot( sacp1_dist(with10), sacv_dur(with10), 'r+');
set(l1,'markersize',mrkrsz);
l1=plot( sacp1_dist(with20), sacv_dur(with20), 'g+');
set(l1,'markersize',mrkrsz);
l1=plot( sacp1_dist(with30), sacv_dur(with30), 'b+');
set(l1,'markersize',mrkrsz);
l1=plot( sacp1_dist(anti10), sacv_dur(anti10), 'rx');
set(l1,'markersize',mrkrsz);
l1=plot( sacp1_dist(anti20), sacv_dur(anti20), 'gx');
set(l1,'markersize',mrkrsz);
l1=plot( sacp1_dist(anti30), sacv_dur(anti30), 'bx');
set(l1,'markersize',mrkrsz);
max_y = max( max(sacv_dur), max(dur_bah) );
%plot(ampl_vec, dur_bah, 'b')
temp=plot(ampl_vec, dur_yar,  'c');
set(temp,'Color',[0.75 0.75 0.75]);
set(gca,'Xlim',[0 max_ampl]);
ylabel('Sac. Dur. (msec) [vdcp]')

subplot(2,2,3)
hold on; box on
plot( sacp1_dist(ind0),         sacp1_dur(ind0),      'w.')
l1=plot( sacp1_dist(with_all),  sacp1_dur(with_all),  'b+');
set(l1,'markersize',mrkrsz);
l1=plot( sacp1_dist(anti_all),  sacp1_dur(anti_all),  'mx');
set(l1,'markersize',mrkrsz);
max_y = max( max(sacp1_dur), max(dur_bah) );
%plot(ampl_vec, dur_bah, 'b')
temp=plot(ampl_vec, dur_yar,  'c');
set(temp,'Color',[0.75 0.75 0.75]);
set(gca,'Xlim',[0 max_ampl]);
xlabel('Sac. Size Mod. 1 ()')
ylabel('Sac. Dur. (msec) [pdcp]')

subplot(2,2,4)
hold on; box on
plot( sacp1_dist(ind0),         sacv_dur(ind0),      'w.')
l1=plot( sacp1_dist(with_all),  sacv_dur(with_all),  'b+');
set(l1,'markersize',mrkrsz);
l1=plot( sacp1_dist(anti_all),  sacv_dur(anti_all),  'mx');
set(l1,'markersize',mrkrsz);
max_y = max( max(sacv_dur), max(dur_bah) );
%plot(ampl_vec, dur_bah, 'b')
temp=plot(ampl_vec, dur_yar,  'c');
set(temp,'Color',[0.75 0.75 0.75]);
set(gca,'Xlim',[0 max_ampl]);
xlabel('Sac. Size Mod. 1 ()')
ylabel('Sac. Dur. (msec) [vdcp]')

figure('Name','Duration vs Amplitude (Aggregate)','NumberTitle','off');
subplot(2,1,1)
title([files_str '  (Aggregate)'])
hold on; box on
plot(sacp1_dist, sacp1_dur, 'w.')
set(gca,'Xlim',[0 max_ampl]);
temp=plot(ampl_vec, dur_yar,  'c');
set(temp,'Color',[0.75 0.75 0.75]);
xlabel('Sac. Size Mod. 1 ()')
ylabel('Sac. Dur. (msec) [pdcp]')

subplot(2,1,2)
hold on; box on
plot(sacp1_dist, sacv_dur, 'w.')
temp=plot(ampl_vec, dur_yar,  'c');
set(temp,'Color',[0.75 0.75 0.75]);
set(gca,'Xlim',[0 max_ampl]);
xlabel('Sac. Size Mod. 1 ()')
ylabel('Sac. Dur. (msec) [vdcp]')

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if ~exist('export') export = 0; end
if export
   clear mainseqmat stdline
   expdir
   mainseqmat(:,1) = sacp_dist;
   mainseqmat(:,2) = sacv1_dist;
   mainseqmat(:,3) = sacv2_dist;
   mainseqmat(:,4) = sacp_dur;
   mainseqmat(:,5) = sacv_dur;
   mainseqmat(:,6) = norm_max_vel;
   mainseqmat(:,7) = true_max_vel;
   
   stdline(:,1) = ampl_vec';
   stdline(:,2) = dur_yar';
   stdline(:,3) = dur_bah';
   stdline(:,4) = PV_Bah';
   stdline(:,5) = PV_ZS';

   indmat(:,1) = with10;
   indmat(:,2) = with20;
   indmat(:,3) = with30;
   indmat(:,4) = anti10;
   indmat(:,5) = anti20;
   indmat(:,6) = anti30;
   indmat(:,7) = with_all;
   indmat(:,8) = anti_all;

   save mainseq.txt mainseqmat -ascii
   save stdline.txt stdline -ascii
   save indmat.txt indmat -ascii
   omdir
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if ~exist('debugme') debugme = 0; end
if ~debugme
   clear nRows nCols num_pts z when when_sec title_str files_str
   clear this_saci_dist this_sacp_dist this_sacf_dist
   clear this_max_vel true_max_vel norm_mav_vel this_max_v_pt
   clear sacv_dur this_sacv_dur sacp_dur this_sacp_dur this_samp_freq
   clear this_sacv_on this_sacv_off this_sacp_on this_sacp_off
   clear saci_dist sacp_dist sacf_dist sacv1_dist sacv2_dist
   clear init_eye_vel cyc_beg_list cyc_end_list mrkrsz l1
   clear PV_ZS PV_Bah dur_yar dur_bah max_y
end
