% NAFXest.m: estimate % improvement in NAFX.
% Usage: out = nafxest(inputValue, rr);
%
% inputValue is the number to be converted.
% rr = 1 returns 'out' as Estimated % Improvement in NAFX.
%    = 2 returns 'out' as Estimated Post-Op NAFX.
%    = 3 returns 'out' as Estimated % Improvement in, and Post-Op, NAFX.
%
% Alternatively, you can simply type "nafxest" and follow the prompts
% To plot the estimated NAFX improvement function, use 'NAFXestplot'
% Written by LF Dell'Osso on 4/9/09
% Last modified: 4/9/09 by LF Dell'Osso


function out = nafxest(inpVal, rr)

if nargin == 0
   inpVal=-1;
   verbose=1;
 elseif nargin == 1
     disp(' NAFXest requires either 2 arguments (NAFXpre, 1-3) or none')
 return
    else
    verbose=0;
end

while (nargin == 0) | (nargin == 2)
 if nargin <2
   disp(' 0) Quit')
   disp(' 1) Convert Pre-Op NAFX to Estimated % Improvement in NAFX')
   disp(' 2) Convert Pre-Op NAFX to Estimated Post-Op NAFX')
   disp(' 3) Convert Pre-Op NAFX to Estimated % Improvement in, and Post-Op, NAFX')
   rr = input(' --> ');
 end

   switch rr
    case 0
       disp('aborting')
    return
    case 1
      if nargin == 0
      nafx_pre = input('Enter the Pre-Op NAFX: ');
       else
        nafx_pre = inpVal;
      end

       while (nafx_pre<=0.68)
        nafx_impr = round(-63.23*log(nafx_pre) - 17.2);
        % nafx_impr = -63.23*log(nafx_pre) - 17.2;
       
         if verbose
          disp(['  % NAFX Improvement estimated to be ' num2str(nafx_impr, '%4.0f') ' %'])
          return
         end
      out = nafx_impr;
      return
       end
       
        while (1-nafx_pre<0.32)
         nafx_impr = round(-111.26*(nafx_pre).^4 +6.0003*(nafx_pre).^3 +543.54*(nafx_pre).^2 -675.93*(nafx_pre) +237.64);
         % nafx_impr = -111.26*(nafx_pre).^4 +6.0003*(nafx_pre).^3 +543.54*(nafx_pre).^2 -675.93*(nafx_pre) +237.64;
       
         if verbose
          disp(['  % NAFX Improvement estimated to be ' num2str(nafx_impr, '%4.0f') ' %'])
          return
         end
      out = nafx_impr;
      return
        end
       
    case 2         
      if nargin == 0
       nafx_pre = input('Enter the Pre-Op NAFX: ');
        else
         nafx_pre = inpVal;
      end

       while (nafx_pre<=0.68)
        nafx_post = (-63.23*log(nafx_pre) - 17.2)*(nafx_pre)/100 + nafx_pre;
       
        if verbose
         disp(['  % Post-Op NAFX estimated to be ' num2str(nafx_post, '%4.3f')])
         return
        end
    out = nafx_post;
    return
       end
       
        while (1-nafx_pre<0.32)
        nafx_post = (-111.26*(nafx_pre).^4 +6.0003*(nafx_pre).^3 +543.54*(nafx_pre).^2 -675.93*(nafx_pre) +237.64)*(nafx_pre)/100 + (nafx_pre);
       
        if verbose
         disp(['  % Post-Op NAFX estimated to be ' num2str(nafx_post, '%4.3f')])
         return
        end
    out = nafx_post;
    return
        end

    case 3
      if nargin == 0
      nafx_pre = input('Enter the Pre-Op NAFX: ');
       else
        nafx_pre = inpVal;
      end

       while (nafx_pre<=0.68)
        nafx_impr = round(-63.23*log(nafx_pre) - 17.2);
        nafx_post = (-63.23*log(nafx_pre) - 17.2)*(nafx_pre)/100 + nafx_pre;
       
        if verbose
         disp(['  % NAFX Improvement estimated to be ' num2str(nafx_impr, '%4.0f') ' %'])
         disp(['  % Post-Op NAFX estimated to be ' num2str(nafx_post, '%4.3f')])
         return
        end
       out(1) = nafx_impr;
       out(2) = nafx_post;
       return
       end
       
       while (1-nafx_pre<0.32)
        nafx_impr = round(-111.26*(nafx_pre).^4 +6.0003*(nafx_pre).^3 +543.54*(nafx_pre).^2 -675.93*(nafx_pre) +237.64);
        nafx_post = (-111.26*(nafx_pre).^4 +6.0003*(nafx_pre).^3 +543.54*(nafx_pre).^2 -675.93*(nafx_pre) +237.64)*(nafx_pre)/100 + (nafx_pre);
       
        if verbose
         disp(['  % NAFX Improvement estimated to be ' num2str(nafx_impr, '%4.0f') ' %'])
         disp(['  % Post-Op NAFX estimated to be ' num2str(nafx_post, '%4.3f')])
         return
        end
       out(1) = nafx_impr;
       out(2) = nafx_post;
       return
       end

    otherwise
     disp([num2str(rr) ' is not a valid choice'])
     
   end  %% switch rr
end  %% while