% OMpath.m: add the directories needed to use the
% OMtools analysis m-files.
% Written by:  Jonathan Jacobs
%              December 1995 - June 2009  (last mod: 06/20/09)

% 21 March 2003: added '/' as sep character for MATLAB 6.5 (OS X, yay!)
% 24 March 2003: added sep2 for UNIX (ML6.5 on OS X)
% 20 June 2009:  added 'overrides' directory.  loads BEFORE standard ML toolboxes 
function OMpath()

global dataroot OMroot

[comp, maxsize] = computer;
vers=version;
P = path;
disp( 'Setting OMtools paths.' )
if comp(1) == 'M' & vers(1)<='5' % 'classic' Mac OS
   sep  = ':';                   % between dirs in a single path
   sep2 = ';';                   % between path entries
 elseif comp(1) == 'P'           % PC
   sep  = '\'; 
   sep2 = ';';
 else                            % Unix (including Mac OS X)
   sep  = '/';
   sep2 = ':';    
end

% generally 'OMroot' will just be the MATLAB directory,
% but you can change it to whatever suits your needs.
% This could be useful if you need to run MATLAB 4 and MATLAB 5
% and only want to have one OMtools installation.  
% find the root directory for the data files.
cd([OMroot sep 'OMtools'])

% add 'overrides' to appear BEFORE any MATLAB built-in functions
% if using R2012a or later, can ignore Overrides, since ML defaults to proper java windows
temp=ver('MATLAB');
ML_VER = str2num(temp.Version);
if (ML_VER >= 7.13) && (ML_VER <= 8.1)
	over_dir = [OMroot sep 'OMtools' sep 'overrides'];
	if exist(over_dir,'dir')
	   P = path( [OMroot sep 'OMtools' sep 'overrides' sep2], P);
	end
end

% core stuff.  should ALWAYS be present
add = '';
add = [add OMroot sep 'OMtools' sep2];
if exist('omprefs','dir'),   add = [add OMroot sep 'OMtools' sep 'omprefs' sep2];   end
add = [add OMroot sep 'OMtools' sep 'rd' sep2];
add = [add OMroot sep 'OMtools' sep 'rd' sep 'pickdata' sep2];
add = [add OMroot sep 'OMtools' sep 'utils' sep2];
add = [add OMroot sep 'OMtools' sep 'utils' sep 'filt' sep2];
add = [add OMroot sep 'OMtools' sep 'analysis' sep2];
add = [add OMroot sep 'OMtools' sep 'analysis' sep 'tplot3' sep2];
add = [add OMroot sep 'OMtools' sep 'labels' sep2];
add = [add OMroot sep 'OMtools' sep 'datadirs' sep2];

% might not be present in some installations
if exist('personal','dir'),   add = [add OMroot sep 'OMtools' sep 'personal' sep2];   end
if exist('graphing','dir'),   add = [add OMroot sep 'OMtools' sep 'graphing' sep2];   end
if exist('zoomtool','dir'),   add = [add OMroot sep 'OMtools' sep 'zoomtool' sep2];   end
if exist('eyeballs3d','dir'), add = [add OMroot sep 'OMtools' sep 'eyeballs3d' sep2]; end
if exist('simstuff','dir')
	add = [add OMroot sep 'OMtools' sep 'simstuff' sep2];
	add = [add OMroot sep 'OMtools' sep 'simstuff' sep 'misc' sep2];
	add = [add OMroot sep 'OMtools' sep 'simstuff' sep 'diagrams' sep2];
	add = [add OMroot sep 'OMtools' sep 'simstuff' sep 'common' sep2];
	add = [add OMroot sep 'OMtools' sep 'simstuff' sep 'LNsim' sep2];
	add = [add OMroot sep 'OMtools' sep 'simstuff' sep 'LNsim' sep 'mfiles' sep2];
	add = [add OMroot sep 'OMtools' sep 'simstuff' sep 'CNsim' sep2];
	add = [add OMroot sep 'OMtools' sep 'simstuff' sep 'CNsim' sep 'mfiles' sep2];
	add = [add OMroot sep 'OMtools' sep 'simstuff' sep 'SPsim' sep2];
	add = [add OMroot sep 'OMtools' sep 'simstuff' sep 'SPsim' sep 'mfiles' sep2];
	add = [add OMroot sep 'OMtools' sep 'simstuff' sep 'SaccSim' sep2];
	add = [add OMroot sep 'OMtools' sep 'simstuff' sep 'SaccSim' sep 'mfiles' sep2];
end
path( P, add );

setroot
% find the root directory for the data files.
% this code duplicates code found in setroot and startup,
% but what the hey: better safe than sorry, right?

cd(findomprefs)
datarootfid = fopen( 'dataroot.txt', 'r' );
if datarootfid > 0
   dataroot = fread(datarootfid);
   dataroot = setstr(dataroot');
   dataroot = strtok(dataroot,[10 13]);
   dataroot = deblank(dataroot);
   fclose(datarootfid);
 else
   fid=fopen('dataroot.txt','w');
   fwrite(fid, matlabroot, 'char');
   fclose(fid);
   dataroot = matlabroot;
   disp('<<<OMpath.m>>>')
   disp('"dataroot.txt" missing from "MATLAB" directory.')
   disp('I have created a new copy, initialized to the')
   disp('"MATLAB" root directory.  Feel free to modify it.')
end
cd(matlabroot)
