% savefig.m: saves a figure (optionally with a specified fig number) to disk.
%   e.g.: savefig('testfig', 1);
% If no figure number is specified the frontmost figure is stored.
% If no file name is given, 'savefig' opens a file select box.
% The save path is stored in 'savefig.ini' in the 'omprefs' directory.
% (If one does not exist, it will be created in your MATLAB root directory)

% Written by: Jonathan Jacobs
%             March 1997 - September 2004  (last mod: 09/23/04)

function size = savefig(fileName, figHand)

if nargin ~= 2
  fileName = 'notyet';
  figHand=findHotW;
  if figHand < 0
    disp('No figure window available to save')
    return
  end
end

figure(figHand)

[comp, maxsize] = computer;
v = version;
if comp(1) == 'M'
   if v(1) <= '5'
      sep = ':';
     else 
      sep = '/';
   end   
 else
   sep = '\';
end

if v(1) <= '6'
   saveformat = '.m';
 else
   saveformat = '.fig';
end

currentdir=pwd;

wname = get(findHotW,'Name');
if isempty(wname), wname = ['untitled' saveformat]; end
%ptpos_temp = findstr(wname,'.');
%ptpos = ptpos_temp(end);
savename = wname;
%savename = wname(1:ptpos+1);

savePath = currentdir;
%savePath = [matlabroot, sep];

if nargin < 2
   % find and load the last path, stored in 'savefig.ini' as 'savePath'
   cd(matlabroot)
   gp_err=0; loaderr=0;
   eval('cd(findomprefs)','gp_err=1;')
   if gp_err % must make a omprefs directory and create a 'savefig.ini' file
      mkdir('omprefs')
      cd('omprefs')
      savePath = [matlabroot, sep];
      save('savefig.ini', 'savePath');
   end
   eval(['load savefig.ini -mat;'],['loaderr=1;']);
   if loaderr, savePath = pwd; end

   cd(currentdir)

   if exist(savePath(1:end-1),'dir')
%      cd(savePath(1:end-1))
    else
      disp(['The directory ' '''' savePath(1:end-1) '''' ' no longer exists.'])
      disp('Choose a new directory to save the figure.')
   end

   fileformatlist = {'.fig';'.jpg';'.eps'};
   prompt = ['Save Figure No.', int2str(figHand)];
   [fileName,savePath,filterindex] = uiputfile(fileformatlist, prompt, savename);
   %[fileName,savePath] = uiputfile(savename,prompt);
   if fileName == 0
      disp( 'Save canceled.')
      return
   end

   if savePath
      %cd(matlabroot)
      cd(findomprefs)
      eval('save savefig.ini savePath;');
   end

 else
   savePath=('');		
end


% append appropriate file extension to filename if needed
saveformat = fileformatlist{filterindex};
dotpos_temp = findstr(fileName,'.');
if ~isempty(dotpos_temp)
	dotpos = dotpos_temp(end);
 else
	dotpos = length(fileName)+1;
end

if strcmpi(fileName(end-1:end), saveformat)
  % all is well
 else
   fileName = [fileName(1:dotpos-1) saveformat];
end


% save the figure
set(figHand,'Name',[fileName])
%set(figHand,'Name',[fileName ' (saved)'])
if v(1) <= '5'
   eval([ 'print -dmfile ' '''' savePath fileName '''' ]);  
  else
   saveas(gcf,[savePath fileName])
end
disp (['Saving as:  ', savePath, fileName]);


% Mac only: if 'filetype.m' and 'filetype.mex' are present we will use them
if strcmp(comp,'MAC2') & exist('filetype.m')==2 & exist('filetype.mex')==3
   if ~isempty(savePath),		%% ps added 16 Oct 2002
      initpath = pwd;
      eval(['cd ' '''' savePath ''''])
   end
   [oldtype,oldcreator]=filetype(fileName,'TEXT','MATL');
   if ~isempty(savePath),		%% ps added 16 Oct 2002
      eval(['cd ' '''' initpath ''''])
   end
end

eval(['cd ' '''' currentdir ''''],['']) 