% drawbox.m: draw a box
% Usage: drawbox(xlimit, ylimit, linColor, fillColor, linStyle)
% Defaults: xlimit, ylimit = 0.5
%           linColor = 'w'
%           fillColor = 'none'
%           linStyle  = '--'  (dashed)
% Note: All arguments are optional.  However if you supply any argument,
% you MUST also specify the preceding arguments.
% e.g.  drawbox(3, 1.5, 'g') will plot a green box +/-3.0 horizontal
%                                                  +/-1.5 vertical
%       drawbox(1, 1, [0.5, 0.5, 0.5]) will plot a gray box of +/-1 h & v
%       drawbox(1, 2, 'r', 'g')      will plot a solid red box +/-1.0 hor, +/-2.0 vert,
%                                    bordered by a dashed green line
%       drawbox(1, 2, 'r', 'g', '-') will plot a solid red box +/-1.0 hor, +/-2.0 vert,
%                                    bordered by a solid green line

% written by :  Jonathan Jacobs
%               February 1997 - March 1998 (last mod: 03/23/98)

function drawbox(xlim,ylim,linColor,fillColor,linStyle)

if nargin==1 | nargin>5
   help drawbox
   return
end

if nargin<5
   linStyle = '--';
end

if nargin<4
   fillColor = 'none';
end

if nargin<3
   linColor = 'w';
end

if nargin==0
   xlim = 0.5; % default
   ylim = 4.0; % default
end

if fillColor == 0
   fillColor = 'none';
end

hold on

if isempty(fillColor) | strcmp(fillColor,'none')
   %disp('no fill')
   linHand  = line([-xlim xlim xlim -xlim -xlim],[-ylim -ylim ylim ylim -ylim]);
   set(linHand,'color',linColor);
   set(linHand,'LineStyle',linStyle);
else
   %disp('fill')
   fillHand = fill([-xlim xlim xlim -xlim -xlim],[-ylim -ylim ylim ylim -ylim],[0 0 0]);
   set(fillHand,'FaceColor',fillColor);
   linHand  = line([-xlim xlim xlim -xlim -xlim],[-ylim -ylim ylim ylim -ylim]);
   set(linHand,'color',linColor);
   set(linHand,'LineStyle',linStyle);
   set(linHand,'LineWidth',2);
end
