% drawcirc.m: draw an circle or ellipse
% Usage: drawcirc(xlimit, ylimit, linColor, fillColor, linStyle)
% Defaults: xlimit, ylimit = 0.5
%           linColor = 'w'
%           fillColor = 'none'
%           linStyle  = '--'  (dashed)
% Note: All arguments are optional.  However if you supply any argument,
% you MUST also specify the preceding arguments.
% e.g.  drawcirc(3, 1.5, 'g') will plot a green ellipse +/-3.0 horizontal
%                                                      +/-1.5 vertical
%       drawcirc(1, 1, [0.5, 0.5, 0.5]) will plot a gray circle of +/-1 h & v
%       drawcirc(1, 2, 'r', 'g')      will plot a solid red ellipse +/-1.0 hor, +/-2.0 vert,
%                                     bordered by a dashed black line
%       drawcirc(1, 2, 'r', 'g', '-') will plot a solid red ellipse +/-1.0 hor, +/-2.0 vert,
%                                     bordered by a dashed black line

% written by :  Jonathan Jacobs
%               February 1997 - March 1998 (last mod: 03/23/98)

function drawcirc(xlim,ylim,linColor,fillColor,linStyle)

if nargin==1 | nargin>5
   help drawcirc
   return
end

if nargin<5
   linStyle = '--';
end

if nargin<4
   fillColor = 'none';
end

if nargin<3
   linColor = 'w';
end

if nargin==0
   xlim = 0.5; % default
   ylim = 0.5; % default
end

if fillColor == 0
   fillColor = 'none';
end

hold on

vect = -0.1:0.1:2*pi;
x=xlim*cos(vect);
y=ylim*sin(vect);

if isempty(fillColor) | strcmp(fillColor,'none')
   %disp('no fill')
   linHand  = line(x,y);
   set(linHand,'color',linColor);
   set(linHand,'LineStyle',linStyle);
 else
   %disp('fill')
   fillHand = fill(x,y,[0 0 0]);
   set(fillHand,'facecolor',fillColor);
   linHand  = line(x,y);
   set(linHand,'color',linColor);
   set(linHand,'LineStyle',linStyle);
   set(linHand,'LineWidth',2);
end
