% drawrad.m  plot a foveal radius (default is +/-0.5 deg, centered on 0 deg)
% on top of an existing graph.
% Usage: drawrad( center, radius, start, stop, color, plotCenterLine )
%        where 'center' and 'radius' are in degrees  (default = 0, 0.5)
%              'start' and 'stop' are in seconds     (default = entire plot)
%              'color' is either a MATLAB shortcut   (e.g. 'r', 'c', 'y', etc)
%                      or an RGB triplet of the form [0.x 0.y 0.z]
%              'plotCenterLine' = 0 (default) will NOT plot the line between the
%                      two radius lines
% Note: it is not necessary to specify all the input arguments.  However if you
% provide any argument, you must also include all that precede it.  Also note that
% if 'start' is given, 'stop' must also be used.

% written by:  Jonathan Jacobs
%              November 1995 - March 1998 (last mod: 03/12/98)

function drawrad( center_radius, start_stop, color, showFovPt )

global samp_freq

if nargin == 0
   center = 0;
   radius = 0.5;
   ssFlag = 0;
   color = 'w';
   showFovPt = 0;
 elseif nargin == 1
   radius = 0.5;
   ssFlag = 0;
   color = 'w';
   showFovPt = 0;
 elseif nargin == 2
   ssFlag = 0;
   color = 'w';
   showFovPt = 0;
 elseif nargin == 3 | nargin > 6
   help fovrad
   return
 elseif nargin == 4
   color = 'w';
   ssFlag = 1;
   showFovPt = 0;
 elseif nargin == 5
   ssFlag = 1;
   showFovPt = 0;
 else
   ssFlag = 1;
end

if ssFlag
   if (stop <= start)|(stop == 0)
      ssFlag = 0;
   end
end

% make sure there is reason to use fovrad
if isempty(get(gca, 'children'))
   disp( 'You need to have a data plot to use "fovrad".' )
   close
   return
end

if ~ssFlag
   [xlims] = get(gca,'Xlim');
   first_pt = xlims(1);
   last_pt = xlims(2);
 else
   % use time limits
   first_pt = start;
   last_pt  = stop;
end

x_vect = [first_pt last_pt];

hold on
if showFovPt
   clH=plot(x_vect, center*ones(2,1));       % foveation pt.
   set(clH,'Color',color);
   set(clH,'LineStyle','--');
end
f1H = plot(x_vect, radius+center*ones(2,1)); % +foveal extent
f2H = plot(x_vect,-radius+center*ones(2,1)); % -foveal extent
set(f1H,'LineStyle','-.');
set(f2H,'LineStyle','-.');
set(f1H,'Color',color);
set(f2H,'Color',color);
