% enviro.m: show/change enviroment settings
% enviro looks for the file 'enviroG.mat' in the 'RD' folder.  If it does not
% find it, a new file (initialized to zeros) will be generated.
% Usage: enviro
%
% This is a GUI-based interface, so all the settings are visible.  Hopefully,
% they are intuitively named.  When in doubt, don't screw with a setting.

% written by:  Jonathan Jacobs
%              March 1997 - March 2004 (last mod:  03/10/04)

gp_err = 0;
oldpath = pwd;
cd(matlabroot)
eval('cd(findomprefs)','gp_err=1;')
if gp_err % must make a omprefs directory
   mkdir('omprefs')
   cd('omprefs')
end

numVars = 11;
loaderr=0;

eval('load enviroG.mat','loaderr=1;')
if loaderr
   disp('''enviroG.mat'' not found.  Initializing to defaults.')
   %enviroG=zeros(numVars,1);
   enviroG=[0 1 1 1 1 1 1 0 0 0 1];
end
cd(oldpath)

if length(enviroG) ~= numVars
   disp('Length of enviroG does not match number of settings.')
   disp('I will pad enviroG to match.  But you must verify your settings.')
   enviroG = [enviroG zeros(numVars-length(enviroG))];
end

envStr(1,:)  = 'showGraphs ';
envStr(2,:)  = 'doLoadSacs ';
envStr(3,:)  = 'doScaling  ';
envStr(4,:)  = 'doRefix    ';
envStr(5,:)  = 'doFiltering';
envStr(6,:)  = 'doUnfolding';
envStr(7,:)  = 'doXTalkRmvl';
envStr(8,:)  = 'doHeadAdj  ';
envStr(9,:)  = 'debugme    ';
envStr(10,:) = 'export     ';
envStr(11,:) = 'useTimeAxis';

% set up the ui
fig_width = 110;
fig_height = (25*numVars) + 40;
startXPos = 20;
startYPos = (480 - fig_height)/2;
enviroWinH = figure('pos',[startXPos, startYPos, fig_width, fig_height],...
       'Resize', 'off', 'Name', 'Enviro!',...
       'NumberTitle', 'off', 'NextPlot', 'new',...
       'MenuBar', 'none',...
       'Tag', 'EditingWindow');

y_pos = fig_height;
for j = 1:numVars 
   y_pos = y_pos - 25;
   uicontrol('Style', 'text', 'Units', 'pixels',...
      'Position',[5 y_pos 70 20],...  
      'String', envStr(j,:) )      

   varH(j) = uicontrol('Style','edit','Units','pixels',...
      'BackgroundColor','magenta','ForeGroundColor','white',...
      'Position',[80 y_pos 25 20],...
      'String',num2str(enviroG(j)),...
      'UserData',j,'Tag', '',...
      'Callback',['which=get(gco,''UserData'');',...
                  'newVal = str2num(get(varH(which), ''String''));',...
                  'if (newVal == 1) | (newVal == 0),',...
                  '   enviroG(which) = newVal;',...
                  ' else,',...
                  '   set(varH(which),''String'',num2str(enviroG(which)) );',...
                  'end;' ]);
end

y_pos = y_pos-30;
doneH = uicontrol('Style','push','Units','pixels',...
    'Position',[5 y_pos 50 20],...
    'String','Done',...
    'UserData','','Tag','',...
    'Callback',['oldpath = pwd;',...
    		       'cd(matlabroot);','cd(findomprefs);',...
				    'save enviroG.mat  enviroG;',...
                'showGraphs  = enviroG(1);',...
                'doLoadSacs  = enviroG(2);',...
                'doScaling   = enviroG(3);',...
                'doRefix     = enviroG(4);',...
                'doFiltering = enviroG(5);',...
                'doUnfolding = enviroG(6);',...
                'doXTalkRmvl = enviroG(7);',...
                'doHeadAdj   = enviroG(8);',...
                'debugme     = enviroG(9);',...
                'export      = enviroG(10);',...
                'useTimeAxis = enviroG(11);',...
                'close(enviroWinH);',...
                'clear which envStr doneH varH enviroWinH;',...
                'clear fig_width fig_height startXPos startYPos;',...
                'clear loaderr numVars y_pos j newVal enviroG;',...
                'cd(oldpath);']);
