% rd_dig.m:  
% Read in the digital stimulus data.  
%
% written by: Jonathan Jacobs
%             November 2001  (last mod: 11/02/01)
% modified by: King Yi
%              April 2011  (last mod: 4/25/11)
%              - this .m file only works for Vergence or TBI LED Bar, may
%              modify code for other digital stimuli types


digfile = [shortname, '.dig'];
disp( ['Searching ' digfile ' for digital stimulus data.'] )

fid = fopen(digfile,'r');
if fid == -1
   disp( [sprintf('\b') ' ** None found **'] )
   return
end

digfiletext = fread(fid);
digfiletext = setstr(digfiletext');
fclose(fid);

t_stim = []; stim_dur = []; whichLED = []; laser_state = []; vpixx_start = [];

% Determine if Vergence bar or TBI LED bar was used - may modify in the
% future for other digital stimuli types
if (~isempty(strfind(verge_stim,'FNFtrack.vrg')) || ~isempty(strfind(verge_stim,'FNFstep.vrg')))
    LEDangles = [NaN 20 18 16 14 12 10 8 6];  % TBI LED Bar
else
    LEDangles = [NaN -15 -10 -5 0 5 10 15]; % Vergence Bar
end

[headerline, digfiletext, emptyLine, isEOF] = getnextl(digfiletext);

i=1;
[nextline, digfiletext, emptyLine, isEOF] = getnextl(digfiletext);
while ~isEOF
   [wordlist,numwords] = procline(nextline);
   whichLED(i)    = str2num(wordlist(1,:));
   stim_dur(i)    = str2num(wordlist(2,:));
   laser_state(i) = str2num(wordlist(3,:));
   t_stim(i)      = str2num(wordlist(4,:));
   i=i+1;
   [nextline, digfiletext, emptyLine, isEOF] = getnextl(digfiletext);
end

% init_time is the time of 1st analog sample
t_stim = t_stim - init_time;

% Determine if Vergence bar or TBI LED bar was used - may modify in the
% future for other digital stimuli types
if (~isempty(strfind(verge_stim,'FNFtrack.vrg')) || ~isempty(strfind(verge_stim,'FNFstep.vrg')))
    whichLED = log2(whichLED) + 2;    %make '0th' LED #1 in LEDangles list 
    nulls = isinf(whichLED);
    whichLED(nulls) = ones(nulls,1);
else
    % LED table
    % LED ID      Deg
    %    0        NaN
    %    1        -15
    %    2        -10
    %    4         -5
    %    8          0
    %   16          5
    %   32         10
    %   64         15
    %   65    '-15 & 15'    NaN
    %  128      'beep'      NaN
    %  136      'beep & 0'  0

    % Do conversion for digstimplot.m to plot correctly
    %                   LED ID   LEDangles index    LED Deg
    whichLED(whichLED ==    2) =       3;           %  -10
    whichLED(whichLED ==    4) =       4;           %   -5
    whichLED(whichLED ==    8) =       5;           %    0
    whichLED(whichLED ==   16) =       6;           %    5
    whichLED(whichLED ==   32) =       7;           %   10
    whichLED(whichLED ==   64) =       8;           %   15
    whichLED(whichLED ==   65) =       1;           %  -15, 15  
    whichLED(whichLED ==  128) =       1;           %  'beep'
    whichLED(whichLED ==  136) =       5;           %  'beep & 0'
    whichLED(whichLED ==    1) =       2;           %  -15
    whichLED(whichLED ==    0) =       1;           %  NaN, LED Off
end

disp(' To see it, type ''digstimplot'' after plotting the eye movement data.')

clear nulls init_time fid digfiletext i nextline emptyLine isEOF
