% saccgen.m: A primitive CLI program to generate random saccade stimuli.
% (This file is meant to be read by the LabVIEW data acquisition/analog output VI.
% The sampling frequency is 100 Hz, a value that was set by acq_disp_AO.vi
% therefore times can be specified only within 0.01 seconds.
% Usage: out = saccgen;  (use of an output variable is optional)

% Written by:  Jonathan Jacobs
%              March 1999 (last mod: 03/11/99)

function out = saccgen(null);

maxampl = 40;
samptemp = 100;

initialpath = pwd;

t_or_s = 't';
tstr = 'seconds';
sampf = samptemp;

promptstr = 'Enter the number of fixations to make at each position: ';
numfix=-1;
while numfix <= 0
   numfix = input(promptstr);
end

promptstr = 'Enter the duration of each fixation (seconds): ';
saccdur=-1;
while (saccdur<= 0) %| (saccdur>trialdur)
   saccdur = input(promptstr);
end

% generate a uniformly distributed list of fixation positions
tgt = randgen(numfix);

amplvect = [];
for i = 1:length(tgt);
   amplvect = [amplvect; tgt(i)*ones(saccdur*sampf,1)];
end

if nargout ~= 0
   out = amplvect;
end

figure
t=maket(amplvect,sampf);
plot(t,amplvect)
xlabel(['Time (' tstr ')'])
ylabel('Stimulus Amplitude (deg)')
title('STIMGEN output')

disp(' ')
disp('If you are happy with this result, you can save it as an ASCII file')
disp('Otherwise, run "STIMGEN" again.')
yorn=lower(input('Write this to file (y/n)? ','s'));

file = 0;
if yorn=='y'
   [file, path] = uiputfile('*.stm', 'Save As');
end

if file == 0
   %disp('No file written.')
   %eval(['cd ' '''' initialpath ''''])
   return
end

eval(['cd ' '''' path ''''])
eval(['save ' file ' amplvect  -ascii'])
disp(['"' file '" written to "' path '"'])

% if 'filetype.m' and 'filetype.mex' are present we will use 'em
if strcmp(comp,'MAC2') & exist('filetype.m') == 2 & exist('filetype.mex') == 3
   [oldtype,oldcreator]=filetype('adjbias.txt','TEXT','R*ch');
end

%eval(['cd ' '''' initialpath ''''])
