% threshpts.m: Takes an input vector, a threshold and a range
% and returns a vector with NaN wherever the input vector values
% fall outside that range.
%
% USAGE: [outarr, outpts] = threshpts(inarr, thresh, range);
% where inarr  is the original vector  (e.g. lh)
%       thresh is the cutoff value     (e.g. 5 deg/sec)
%       range  = '-' selects all pts between [-thresh, thresh]
%                '+' selects all pts outside [-thresh, thresh]
%       outarr is the resulting vector (e.g. lht)
%   and outpts is the list of points that were > 0.

% Written by:  Jonathan Jacobs
%              January 2000  (last mod: 01/04/00)

function [outarr,outpts] = threshpts(inarr,thresh,direct)

if nargin < 3
   direct = '-';
end

[r,c]=size(inarr);
if (r>1) & (c>1)
   disp('Please input a ONE-dimensional array.')
   return
end


if direct == '-'
   outpts = find( (inarr<=thresh) & (inarr>=-thresh) );
 elseif direct == '+'
   outpts = find( (inarr>=thresh) | (inarr<=-thresh) );
end

outarr = NaN*ones(r,c);
outarr(outpts) = inarr(outpts);
[numoutpts, numcols] = size(outpts);

disp(['There were ' num2str(numoutpts) ' points in the desired range.'])
