function [h] = crsrmove(ax,name,pos)
%CRSRMOVE Move axes cursor.
%       H=CRSRMOVE(AXES,'NAME',POSITION) moves the named cursor
%       to a new location. It does not change the visibility of
%       the cursor. If the axes handle is not provided, the
%       current axis is used.
%
%       See also CRSRCR, CRSRDEL, CRSRON, CRSROFF

%       Dennis W. Brown 1-10-94
%       Copyright (c) 1994 by Dennis W. Brown
%       May be freely distributed.
%       Not for use in commercial products.
%
%   modified by Jonathan Jacobs to allow dragging of the cursor
%   into sections of data that are NaN.  (Sept 1997)

% Modifications by Jonathan Jacobs
%                  September 1997 - July 1999 (last mod: 07/06/99)

v = version;
v=str2double(v(1:3));

% handles to readouts
temp = get(gca,'UserData');     
editH = temp{1};

% get handle to cursor
h = findline(ax,name);

if v >= 8.4
	% get current axis limits (ML 8.4 and later)
	%xlims = get(ax,'XLim');
	ylims = get(ax,'YLim');
	% get current cursor location
	[xminmax, yminmax] = getpoints(h);
else
	% get current axis data (ML 8.3 and earlier)
	xlims = get(ax,'XLim');
	ylims = get(ax,'YLim');
	xminmax = get(h,'XData');
	yminmax = get(h,'YData');
end

% also added this to most of the routines that call
% "crsrmove", for "belt and suspenders" safety.
if isnan(pos)
   pos = (ylims(1)+ylims(2))/2;
end

% move the cursor
if xminmax(1) == xminmax(2),          % vertical cursor
    % actually move the damn thing
    if v >= 8.4
        clearpoints(h)
        addpoints(h,[pos pos],yminmax);
      else  
        set(h,'XData',[pos pos]);
    end
    % update the numeric display
    if( name < 1999 ),
    	set(editH(9),'String',num2str(pos));
    else
    	set(editH(13),'String',num2str(pos));
    end
    % update the "Delta X" field
    diff = str2double(get(editH(9),'String')) ... 
          - str2double(get(editH(13),'String'));
    set(editH(11),'String',num2str(abs(diff)))

elseif yminmax(1) == yminmax(2) || any(isnan(yminmax)),      % horizontal cursor
    % actually move the damn thing
    if v>=8.4
       clearpoints(h)
       addpoints(h,xminmax, [pos pos]);
    else
       set(h,'YData',[pos pos]);
    end
    
    % update the numeric display
    if( name < 1999 ),
    	set(editH(10),'String',num2str(pos));
    else
    	set(editH(14),'String',num2str(pos));
    end
    % update the "Delta Y" field
    diff = str2double(get(editH(10),'String')) ... 
          - str2double(get(editH(14),'String'));
    set(editH(12),'String',num2str(abs(diff)))

else
%    disp('cursormv: Invalid cursor found...');
%    keyboard
    error('cursormv: Invalid cursor found...');
end;
