function scrllft(ga)
%  function to scroll window to the left
%  written by: Peg Skelly & Jonathan Jacobs
%              September 1995 - September 1997 (last mod: 9/5/97)

if nargin ~= 1,
   ga = gca;
end

% find parent window
gf = get(ga,'Parent');

% get the current axes limits
xxlim = get(ga,'Xlim');
% get the data limits and the x-axis increment (x(2) - x(1))
x_vect = get(findline(ga,'zoomed'),'XData');
xmin = min(x_vect);
xmax = max(x_vect);
x_incr = x_vect(2) - x_vect(1); 

% check to see if move will go past data limits
%  and set new axis limits
if xxlim(1)-(xxlim(2)-xxlim(1)) <= xmin,
   newxlim(1) = xmin;
   newxlim(2) = xmin + (xxlim(2)-xxlim(1));
 else
   newxlim(2) = xxlim(1) - x_incr;
   newxlim(1) = xxlim(1) - x_incr - (xxlim(2)-xxlim(1));
end;

% set new x limits
set(ga,'XLim',[newxlim]);

% get vertical cursor positions
v1 = crsrloc(ga,1001);
v1rel = v1 - xxlim(1);		%% dist v1 is from old left axis limit
v2 = crsrloc(ga,2001);
v2rel = v2 - xxlim(1);		%% dist v2 is from old left axis limit

% get x and y data to find new cursor points
x = get(findline(ga,'zoomed'),'XData');
y = get(findline(ga,'zoomed'),'YData');

%  find new positions for the cursors
v1 = newxlim(1) + v1rel;
if v1 > xmax, v1 = xmax; end
v2 = newxlim(1) + v2rel;
if v2 > xmax, v2 = xmax; end

% get coresponding horizontal cursor values
% cursor one
index1 = find( x >= v1 );
vector = x(index1);
v1 = vector(1);
vector = y(index1);
h1 = vector(1);

% cursor two
index2 = find( x >= v2 );
vector = x(index2);
v2 = vector(1);
vector = y(index2);
h2 = vector(1);

% move the cursors
crsrmove(ga,1001,v1);
crsrmove(ga,1002,h1);
crsrmove(ga,2001,v2);
crsrmove(ga,2002,h2);

% handles to readouts
temp = get(ga,'UserData');     
h = temp{1};
     
set(h(9),'String',num2str(v1));
set(h(10),'String',num2str(h1));
set(h(13),'String',num2str(v2));
set(h(14),'String',num2str(h2));
set(h(11),'String',num2str(abs(v2-v1)));
set(h(12),'String',num2str(abs(h2-h1)));

% adjust horizontal cursor lengths
set(findline(ga,1002),'XData',newxlim);
set(findline(ga,2002),'XData',newxlim);
