function zoomxout(ga)
% ZOOMXOUT Used by ZOOMTOOL to zoom the x axis out.
%       ZOOMXOUT(H) where H is the axis ZOOMTOOL is active in.
%
%       See also ZOOMCLR ZOOMDOWN ZOOMLEFT ZOOMMENU ZOOMMOVE
%           ZOOMPKLF ZOOMPKRT ZOOMRGHT ZOOMSET ZOOMTGGL ZOOMTOOL
%           ZOOMUP ZOOMXFUL ZOOMXIN ZOOMXOUT ZOOMYFUL ZOOMYIN
%           ZOOMYOUT

%       Copyright (c) 1994 by Dennis W. Brown
%       May be freely distributed. Not for use in commercial products.

if nargin ~= 1,
    ga = gca;
end;
gf = get(gca,'Parent');

% get zoomxout stack
temp = get(ga,'UserData');     
h = temp{1};
zout = h(2);			% ZxO
stack = get(zout,'UserData');

% check for empty stack
if isempty(stack), return; end;

% pop last from stack
[m,n] = size(stack);
v1 = stack(m,1);
v2 = stack(m,2);
stack = stack(1:m-1,:);
set(zout,'UserData',stack);

% set new x limits
set(ga,'XLim',[v1 v2]);

% adjust horizontal cursor lengths
v = version;
v=str2double(v(1:3));
if v >= 8.4
	c1h = findline(ga,1002);
	c2h = findline(ga,2002);
	[~,oldc1hY] = getpoints(c1h);
	[~,oldc2hY] = getpoints(c2h);
	clearpoints(c1h); clearpoints(c2h)
	addpoints(c1h, [v1 v2], oldc1hY ); % ylim vals for vrt crsr
	addpoints(c2h, [v1 v2], oldc2hY ); % ylim vals for vrt crsr
 else
    set(findline(ga,1002),'XData',[v1 v2]);
    set(findline(ga,2002),'XData',[v1 v2]);
end
