function zoomyout(ga)
% ZOOMYOUT Used by ZOOMTOOL to zoom the y axis out.
%       ZOOMYOUT(H) where H is the axis ZOOMTOOL is active in.
%
%       See also ZOOMCLR ZOOMDOWN ZOOMLEFT ZOOMMENU ZOOMMOVE
%           ZOOMPKLF ZOOMPKRT ZOOMRGHT ZOOMSET ZOOMTGGL ZOOMTOOL
%           ZOOMUP ZOOMXFUL ZOOMXIN ZOOMXOUT ZOOMYFUL ZOOMYIN
%           ZOOMYOUT

%       Copyright (c) 1994 by Dennis W. Brown
%       May be freely distributed. Not for use in commercial products.

if nargin ~= 1,
    ga = gca;
end;
gf = get(gca,'Parent');

% get zoomyout stack
temp = get(ga,'UserData');     
h = temp{1};
zout = h(5);
stack = get(zout,'UserData');

% check for empty stack
if isempty(stack), return; end;

% pop last from stack
[m,n] = size(stack);
v1 = stack(m,1);
v2 = stack(m,2);
stack = stack(1:m-1,:);
set(zout,'UserData',stack);

% set new y limits
set(ga,'YLim',[v1 v2]);

% adjust vertical cursor lengths
v = version;
v=str2double(v(1:3));
if v >= 8.4
	c1v = findline(ga,1002);
	c2v = findline(ga,2002);
	[oldc1hX, ~] = getpoints(c1v);
	[oldc2hX, ~] = getpoints(c2v);
	clearpoints(c1v); clearpoints(c2v)
	addpoints(c1v, oldc1hX, newylim ); % ylim vals for vrt crsr
	addpoints(c2v, oldc1hX, newylim ); % ylim vals for vrt crsr
 else
 	set(findline(ga,1001),'YData',[v1 v2]);
	set(findline(ga,2001),'YData',[v1 v2]);
end
